HttpsReply class final

The server's answer.

Constructors

HttpsReply(int status, {Map<String, String> headers = const {}, List<int>? body})
const
HttpsReply.json(int status, Map<String, dynamic> document)
A JSON body, with Content-Type: application/json (4).
factory

Properties

body → List<int>?
Null for the body-less answers: 202, 204, and the transport-level 404, 405, 413 and 415.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited